## Limits ant troubleshooting

### Limits
If you wish to annotate thousands of variants, please log in to https://genebe.net, generate an API Key, and provide them using `username` and `api_key`.

The number of daily requests from a single IP is restricted to prevent abuse and excessive resource consumption on our server. Account holders with an API Key enjoy significantly higher limits (in the tens of thousands). If you require a higher daily request limit, please reach out to us via the https://genebe.net .

You can always check your current usage running

```bash
genebe account
```

or
```bash
genebe account --username YOUR_USERNAME --api_key YOUR_API_KEY
```

### Troubleshooting and issues
Experiencing issues? Follow these steps:

1. Check Existing Issues:

* If you encounter problems, explore existing issues on GitHub https://github.com/pstawinski/pygenebe for possible solutions.

2. Report New Issues:

* Unable to find a resolution? You can report the problem by creating a new issue with a clear description and details on https://github.com/pstawinski/pygenebe .

Your feedback is crucial for improving GeneBe client. Thank you for contributing to the community!
